Interface: TooltipCallbacks | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: TooltipCallbacks<TType, Model, Item>

## # Type parameters

Name | Type
--- | ---
`TType` | extends `ChartType`
`Model` | `TooltipModel`<`TType`>
`Item` | `TooltipItem`<`TType`>

## # Methods

### # afterBody

▸ afterBody(`tooltipItems`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItems` | `Item`[]

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2564
(opens new window)

### # afterFooter

▸ afterFooter(`tooltipItems`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItems` | `Item`[]

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2576
(opens new window)

### # afterLabel

▸ afterLabel(`tooltipItem`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItem` | `Item`

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2568
(opens new window)

### # afterTitle

▸ afterTitle(`tooltipItems`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItems` | `Item`[]

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2561
(opens new window)

### # beforeBody

▸ beforeBody(`tooltipItems`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItems` | `Item`[]

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2563
(opens new window)

### # beforeFooter

▸ beforeFooter(`tooltipItems`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItems` | `Item`[]

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2574
(opens new window)

### # beforeLabel

▸ beforeLabel(`tooltipItem`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItem` | `Item`

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2566
(opens new window)

### # beforeTitle

▸ beforeTitle(`tooltipItems`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItems` | `Item`[]

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2559
(opens new window)

### # footer

▸ footer(`tooltipItems`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItems` | `Item`[]

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2575
(opens new window)

### # label

▸ label(`tooltipItem`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItem` | `Item`

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2567
(opens new window)

### # labelColor

▸ labelColor(`tooltipItem`): `TooltipLabelStyle`

#### # Parameters

Name | Type
--- | ---
`tooltipItem` | `Item`

#### # Returns

`TooltipLabelStyle`

#### # Defined in

index.esm.d.ts:2570
(opens new window)

### # labelPointStyle

▸ labelPointStyle(`tooltipItem`): `Object`

#### # Parameters

Name | Type
--- | ---
`tooltipItem` | `Item`

#### # Returns

`Object`

Name | Type
--- | ---
`pointStyle` | `PointStyle`
`rotation` | `number`

#### # Defined in

index.esm.d.ts:2572
(opens new window)

### # labelTextColor

▸ labelTextColor(`tooltipItem`): `Color`

#### # Parameters

Name | Type
--- | ---
`tooltipItem` | `Item`

#### # Returns

`Color`

#### # Defined in

index.esm.d.ts:2571
(opens new window)

### # title

▸ title(`tooltipItems`): `string` | `string`[]

#### # Parameters

Name | Type
--- | ---
`tooltipItems` | `Item`[]

#### # Returns

`string` | `string`[]

#### # Defined in

index.esm.d.ts:2560
(opens new window)